@@ -24,8 +24,9 @@ sub AUTOLOAD {
 
   $fragment =~ s/.*:://;
 
-  return $self->{fragments}->{$fragment}->()
-    if exists $self->{fragments}->{$fragment};
+#  DISABLE fragment caching, this is slower but the interface works correctly  
+#  return $self->{fragments}->{$fragment}->()
+#    if exists $self->{fragments}->{$fragment};
 
   my $sub = sub {
     my $new = bless({}, __PACKAGE__);
@@ -71,7 +72,7 @@ REST::Cot::Fragment
 
 =head1 VERSION
 
-version 0.001
+version 0.003
 
 =head1 AUTHOR
 
