@@ -24,17 +24,8 @@ sub path {
         return $path if $path;
 
         $path = @{ $self->{args} }?
-        join ( '/', $self->{parent}
-                        ->{path}
-                        ->(),
-                    @{ $self->{args} },
-                    $self->{name}
-        ) :
-        join ( '/', $self->{parent}
-                        ->{path}
-                        ->(),
-                        $self->{name}
-        );
+          join ( '/', $self->{parent}->{path}->(), $self->{name}, @{ $self->{args} } ) :
+          join ( '/', $self->{parent}->{path}->(), $self->{name} );
 
         return $path;
     };
@@ -89,7 +80,7 @@ REST::Cot::Generators
 
 =head1 VERSION
 
-version 0.001
+version 0.003
 
 =head1 AUTHOR
 
